@@ -7,10 +7,10 @@
  *		HAVE_* and WITH_* defines are substituted at
  *		build time by make with values from autoconf.h.
  *
- * Version:	$Id: ab01978cf914db7e0ef6f5c0d6b1a522cea0b712 $
+ * Version:	$Id: bb74e060b9e4c54c94947d7bc9666ea95ff90370 $
  *
  */
-RCSIDH(missing_h, "$Id: ab01978cf914db7e0ef6f5c0d6b1a522cea0b712 $")
+RCSIDH(missing_h, "$Id: bb74e060b9e4c54c94947d7bc9666ea95ff90370 $")
 
 #if 1
 #  include <stdint.h>
@@ -509,6 +509,13 @@ size_t SSL_SESSION_get_master_key(const SSL_SESSION *s,
 #  endif
 #endif
 
+/*
+ *  NetBSD doesn't have O_DIRECTORY.
+ */
+#ifndef O_DIRECTORY
+#define O_DIRECTORY 0
+#endif
+
 /*
  *	Not really missing, but may be submitted as patches
  *	to the talloc project at some point in the future.
